Django Ancestry Relation
------------------------
Provides an abstract model class for heirarchical data to be stored in a database. 
Provides a manager to interface with the model.

Documentation is in the "docs" directory.

Quick start
-----------
1. Add "django_ancestry_relation" to your INSTALLED_APPS setting like this::
```
INSTALLED_APPS = [
    ...,
    'django_ancestry_relation'
]
```

